<?php

namespace Litecms\Bountysystem\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Bountysystem\Http\Requests\BountysystemRequest;
use Litecms\Bountysystem\Interfaces\BountysystemRepositoryInterface;
use Litecms\Bountysystem\Models\Bountysystem;

/**
 * Resource controller class for bountysystem.
 */
class BountysystemResourceController extends BaseController
{

    /**
     * Initialize bountysystem resource controller.
     *
     * @param type BountysystemRepositoryInterface $bountysystem
     *
     * @return null
     */
    public function __construct(BountysystemRepositoryInterface $bountysystem)
    {
        parent::__construct();
        $this->repository = $bountysystem;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Bountysystem\Repositories\Criteria\BountysystemResourceCriteria::class);
    }

    /**
     * Display a list of bountysystem.
     *
     * @return Response
     */
    public function index(BountysystemRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Bountysystem\Repositories\Presenter\BountysystemPresenter::class)
                ->$function();
        }

        $bountysystems = $this->repository->paginate();

        return $this->response->title(trans('bountysystem::bountysystem.names'))
            ->view('bountysystem::bountysystem.index', true)
            ->data(compact('bountysystems'))
            ->output();
    }

    /**
     * Display bountysystem.
     *
     * @param Request $request
     * @param Model   $bountysystem
     *
     * @return Response
     */
    public function show(BountysystemRequest $request, Bountysystem $bountysystem)
    {

        if ($bountysystem->exists) {
            $view = 'bountysystem::bountysystem.show';
        } else {
            $view = 'bountysystem::bountysystem.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('bountysystem::bountysystem.name'))
            ->data(compact('bountysystem'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new bountysystem.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BountysystemRequest $request)
    {

        $bountysystem = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('bountysystem::bountysystem.name')) 
            ->view('bountysystem::bountysystem.create', true) 
            ->data(compact('bountysystem'))
            ->output();
    }

    /**
     * Create new bountysystem.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BountysystemRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $bountysystem                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('bountysystem::bountysystem.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('bountysystem/bountysystem/' . $bountysystem->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/bountysystem/bountysystem'))
                ->redirect();
        }

    }

    /**
     * Show bountysystem for editing.
     *
     * @param Request $request
     * @param Model   $bountysystem
     *
     * @return Response
     */
    public function edit(BountysystemRequest $request, Bountysystem $bountysystem)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('bountysystem::bountysystem.name'))
            ->view('bountysystem::bountysystem.edit', true)
            ->data(compact('bountysystem'))
            ->output();
    }

    /**
     * Update the bountysystem.
     *
     * @param Request $request
     * @param Model   $bountysystem
     *
     * @return Response
     */
    public function update(BountysystemRequest $request, Bountysystem $bountysystem)
    {
        try {
            $attributes = $request->all();

            $bountysystem->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('bountysystem::bountysystem.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('bountysystem/bountysystem/' . $bountysystem->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('bountysystem/bountysystem/' . $bountysystem->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the bountysystem.
     *
     * @param Model   $bountysystem
     *
     * @return Response
     */
    public function destroy(BountysystemRequest $request, Bountysystem $bountysystem)
    {
        try {

            $bountysystem->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('bountysystem::bountysystem.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('bountysystem/bountysystem/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('bountysystem/bountysystem/' . $bountysystem->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple bountysystem.
     *
     * @param Model   $bountysystem
     *
     * @return Response
     */
    public function delete(BountysystemRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('bountysystem::bountysystem.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('bountysystem/bountysystem'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/bountysystem/bountysystem'))
                ->redirect();
        }

    }

    /**
     * Restore deleted bountysystems.
     *
     * @param Model   $bountysystem
     *
     * @return Response
     */
    public function restore(BountysystemRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('bountysystem::bountysystem.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/bountysystem/bountysystem'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/bountysystem/bountysystem/'))
                ->redirect();
        }

    }

}
