<?php

namespace Litecms\Bountysystem\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Bountysystem\Models\Bountysystem;

class BountysystemPolicy
{

    /**
     * Determine if the given user can view the bountysystem.
     *
     * @param UserPolicy $user
     * @param Bountysystem $bountysystem
     *
     * @return bool
     */
    public function view(UserPolicy $user, Bountysystem $bountysystem)
    {
        if ($user->canDo('bountysystem.bountysystem.view') && $user->isAdmin()) {
            return true;
        }

        return $bountysystem->user_id == user_id() && $bountysystem->user_type == user_type();
    }

    /**
     * Determine if the given user can create a bountysystem.
     *
     * @param UserPolicy $user
     * @param Bountysystem $bountysystem
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('bountysystem.bountysystem.create');
    }

    /**
     * Determine if the given user can update the given bountysystem.
     *
     * @param UserPolicy $user
     * @param Bountysystem $bountysystem
     *
     * @return bool
     */
    public function update(UserPolicy $user, Bountysystem $bountysystem)
    {
        if ($user->canDo('bountysystem.bountysystem.edit') && $user->isAdmin()) {
            return true;
        }

        return $bountysystem->user_id == user_id() && $bountysystem->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given bountysystem.
     *
     * @param UserPolicy $user
     * @param Bountysystem $bountysystem
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Bountysystem $bountysystem)
    {
        return $bountysystem->user_id == user_id() && $bountysystem->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given bountysystem.
     *
     * @param UserPolicy $user
     * @param Bountysystem $bountysystem
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Bountysystem $bountysystem)
    {
        if ($user->canDo('bountysystem.bountysystem.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given bountysystem.
     *
     * @param UserPolicy $user
     * @param Bountysystem $bountysystem
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Bountysystem $bountysystem)
    {
        if ($user->canDo('bountysystem.bountysystem.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
